@@ -5,32 +5,27 @@
 
 from .bind import BindGenerator
 from .gnutls import GnuTLSGenerator
-from .java import JavaGenerator, JavaSystemGenerator
+from .java import JavaGenerator
 from .krb5 import KRB5Generator
 from .libreswan import LibreswanGenerator
 from .libssh import LibsshGenerator
 from .nss import NSSGenerator
 from .openssh import OpenSSHClientGenerator, OpenSSHServerGenerator
-from .openssl import (
-    OpenSSLConfigGenerator,
-    OpenSSLFIPSGenerator,
-    OpenSSLGenerator,
-)
-from .sequoia import RPMSequoiaGenerator
+from .openssl import OpenSSLFIPSGenerator, OpenSSLGenerator
+from .sequoia import RPMSequoiaGenerator, SequoiaGenerator
 
 __all__ = [
     'BindGenerator',
     'GnuTLSGenerator',
     'JavaGenerator',
-    'JavaSystemGenerator',
     'KRB5Generator',
     'LibreswanGenerator',
     'LibsshGenerator',
     'NSSGenerator',
     'OpenSSHClientGenerator',
     'OpenSSHServerGenerator',
-    'OpenSSLConfigGenerator',
     'OpenSSLFIPSGenerator',
     'OpenSSLGenerator',
     'RPMSequoiaGenerator',
+    'SequoiaGenerator',
 ]
